<?php

class Controller { // classe abstraite de contrôleur
	protected $route; // variable protégée contenant le résultat de l'analyse de la requête (dans un tableau)
	protected $view; // variable protégée contenant la vue correspondant à la route donnée
	
	public function __construct($route) { // constructeur
		$this->route = $route; // on stocke la route donnée en paramètre dans la variable protégée du même nom
		$this->view = new View($route); // on instancie une vue avec cette route, et on la stocke dans la variable protégée $view
	}

	static public function slugify($text) { // fonction permettant de transformer une chaîne de caractères en slug
		$text = preg_replace('~[^\pL\d]+~u', '-', $text); // on remplace les caractères qui ne sont pas des lettres ou des chiffres par "-"
		$text = iconv('utf-8', 'us-ascii//TRANSLIT', $text); // on transforme la chaîne pour en retirer les accents
		$text = preg_replace('~[^-\w]+~', '', $text); // on retire les caract-res non désirés (ie les accents seuls)
		$text = trim($text, '-'); // on retire les caractères inutiles en début et fin de chaîne (ie les "-")
		$text = preg_replace('~-+~', '-', $text); // on retire les "-" successifs
		$text = strtolower($text); // on met la chaîne en caractères minuscules

		if (empty($text)) { // si le texte est vide, on retourne par défaut le texte "n-a"
			return 'n-a';
		}

		return $text;
	}
}
